@@ -68,6 +68,8 @@ class MyCache(DistUpgrade.DistUpgradeCache.MyCache):
 
     def __init__(self, progress, rootdir=None):
         apt.Cache.__init__(self, progress, rootdir)
+        # save for later
+        self.rootdir = rootdir
         # raise if we have packages in reqreinst state
         # and let the caller deal with that (runs partial upgrade)
         assert len(self.req_reinstall_pkgs) == 0
@@ -79,6 +81,7 @@ class MyCache(DistUpgrade.DistUpgradeCache.MyCache):
         self._initDepCache()
         self.all_changes = {}
         self.all_news = {}
+        self.pro_versions = {}
         # on broken packages, try to fix via saveDistUpgrade()
         if self._depcache.broken_count > 0:
             self.saveDistUpgrade()
@@ -419,14 +422,22 @@ class MyCache(DistUpgrade.DistUpgradeCache.MyCache):
                         "Please check your Internet connection.")
         self.all_changes[name] += error_message
 
+    # If the machine is not attached to Ubuntu Pro, Update Manager advertises
+    # the upgrades that would be available if it were attached.
+    # As that is unbeknownst to Apt, we need this map to show the correct
+    # version of each upgradable-if-pro-subscribed package.
+    def create_pro_cache(self, pro_pkgs):
+        for (name, version, _a, _a) in pro_pkgs:
+            self.pro_versions[name] = version
+
     def get_changelog(self, name):
         " get the changelog file from the changelog location "
         origins = self[name].candidate.origins
+        version = self.pro_versions.get(name, self[name].candidate.version)
         self.all_changes[name] = _("Changes for %s versions:\n"
                                    "Installed version: %s\n"
                                    "Available version: %s\n\n") % \
-            (name, getattr(self[name].installed, "version", None),
-             self[name].candidate.version)
+            (name, getattr(self[name].installed, "version", None), version)
         if self.CHANGELOG_ORIGIN not in [o.origin for o in origins]:
             self._fetch_changelog_for_third_party_package(name, origins)
             return
