@@ -1,32 +1,36 @@
-# utils.py 
-#  
+# utils.py
+# -*- Mode: Python; indent-tabs-mode: nil; tab-width: 4; coding: utf-8 -*-
+#
 #  Copyright (c) 2011 Canonical
-#  
+#
 #  Author:  Alex Chiang <achiang@canonical.com>
 #           Michael Vogt <michael.vogt@ubuntu.com>
-# 
-#  This program is free software; you can redistribute it and/or 
-#  modify it under the terms of the GNU General Public License as 
+#
+#  This program is free software; you can redistribute it and/or
+#  modify it under the terms of the GNU General Public License as
 #  published by the Free Software Foundation; either version 2 of the
 #  License, or (at your option) any later version.
-# 
+#
 #  This program is distributed in the hope that it will be useful,
 #  but WITHOUT ANY WARRANTY; without even the implied warranty of
 #  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #  GNU General Public License for more details.
-# 
+#
 #  You should have received a copy of the GNU General Public License
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 #  USA
 
 
+from __future__ import print_function
+
 import dbus
 import sys
 
+
 class ModemManagerHelper(object):
 
-    # data taken from 
+    # data taken from
     #  http://projects.gnome.org/NetworkManager/developers/mm-spec-04.html
     MM_DBUS_IFACE = "org.freedesktop.ModemManager"
     MM_DBUS_IFACE_MODEM = MM_DBUS_IFACE + ".Modem"
@@ -36,23 +40,23 @@ class ModemManagerHelper(object):
     MM_MODEM_TYPE_CDMA = 2
 
     # GSM
-    # Not registered, not searching for new operator to register. 
+    # Not registered, not searching for new operator to register.
     MM_MODEM_GSM_NETWORK_REG_STATUS_IDLE = 0
-    # Registered on home network. 
+    # Registered on home network.
     MM_MODEM_GSM_NETWORK_REG_STATUS_HOME = 1
-    # Not registered, searching for new operator to register with. 
+    # Not registered, searching for new operator to register with.
     MM_MODEM_GSM_NETWORK_REG_STATUS_SEARCHING = 2
-    # Registration denied. 
+    # Registration denied.
     MM_MODEM_GSM_NETWORK_REG_STATUS_DENIED = 3
-    # Unknown registration status. 
+    # Unknown registration status.
     MM_MODEM_GSM_NETWORK_REG_STATUS_UNKNOWN = 4
-    # Registered on a roaming network. 
+    # Registered on a roaming network.
     MM_MODEM_GSM_NETWORK_REG_STATUS_ROAMING = 5
 
     # CDMA
     # Registration status is unknown or the device is not registered.
     MM_MODEM_CDMA_REGISTRATION_STATE_UNKNOWN = 0
-    # Registered, but roaming status is unknown or cannot be provided 
+    # Registered, but roaming status is unknown or cannot be provided
     # by the device. The device may or may not be roaming.
     MM_MODEM_CDMA_REGISTRATION_STATE_REGISTERED = 1
     #     Currently registered on the home network.
@@ -62,7 +66,7 @@ class ModemManagerHelper(object):
 
     def __init__(self):
         self.bus = dbus.SystemBus()
-        self.proxy = self.bus.get_object("org.freedesktop.ModemManager", 
+        self.proxy = self.bus.get_object("org.freedesktop.ModemManager",
                                          "/org/freedesktop/ModemManager")
         modem_manager = dbus.Interface(self.proxy, self.MM_DBUS_IFACE)
         self.modems = modem_manager.EnumerateDevices()
@@ -76,12 +80,14 @@ class ModemManagerHelper(object):
     def is_gsm_roaming(self):
         for m in self.modems:
             dev = self.bus.get_object(self.MM_DBUS_IFACE, m)
-            type = self.get_dbus_property(dev, self.MM_DBUS_IFACE_MODEM, "Type")
+            type = self.get_dbus_property(dev, self.MM_DBUS_IFACE_MODEM,
+                                          "Type")
             if type != self.MM_MODEM_TYPE_GSM:
                 continue
-            net = dbus.Interface(dev, self.MM_DBUS_IFACE_MODEM + ".Gsm.Network")
+            net = dbus.Interface(dev,
+                                 self.MM_DBUS_IFACE_MODEM + ".Gsm.Network")
             reg = net.GetRegistrationInfo()
-            # Be conservative about roaming. If registration unknown, 
+            # Be conservative about roaming. If registration unknown,
             # assume yes.
             # MM_MODEM_GSM_NETWORK_REG_STATUS
             if reg[0] in (self.MM_MODEM_GSM_NETWORK_REG_STATUS_UNKNOWN,
@@ -92,12 +98,13 @@ class ModemManagerHelper(object):
     def is_cdma_roaming(self):
         for m in self.modems:
             dev = self.bus.get_object(self.MM_DBUS_IFACE, m)
-            type = self.get_dbus_property(dev, self.MM_DBUS_IFACE_MODEM, "Type")
+            type = self.get_dbus_property(dev, self.MM_DBUS_IFACE_MODEM,
+                                          "Type")
             if type != self.MM_MODEM_TYPE_CDMA:
                 continue
             cdma = dbus.Interface(dev, self.MM_DBUS_IFACE_MODEM + ".Cdma")
             (cmda_1x, evdo) = cdma.GetRegistrationState()
-            # Be conservative about roaming. If registration unknown, 
+            # Be conservative about roaming. If registration unknown,
             # assume yes.
             # MM_MODEM_CDMA_REGISTRATION_STATE
             roaming_states = (self.MM_MODEM_CDMA_REGISTRATION_STATE_REGISTERED,
@@ -109,12 +116,13 @@ class ModemManagerHelper(object):
                 return True
         return False
 
+
 class NetworkManagerHelper(object):
     NM_DBUS_IFACE = "org.freedesktop.NetworkManager"
 
     # connection states
     # Old enum values are for NM 0.7
-    
+
     # The NetworkManager daemon is in an unknown state.
     NM_STATE_UNKNOWN = 0
     # The NetworkManager daemon is connecting a device.
@@ -132,20 +140,20 @@ class NetworkManagerHelper(object):
                                NM_STATE_CONNECTED_SITE,
                                NM_STATE_CONNECTED_GLOBAL]
 
-    # The device type is unknown. 
+    # The device type is unknown.
     NM_DEVICE_TYPE_UNKNOWN = 0
-    # The device is wired Ethernet device. 
+    # The device is wired Ethernet device.
     NM_DEVICE_TYPE_ETHERNET = 1
-    # The device is an 802.11 WiFi device. 
+    # The device is an 802.11 WiFi device.
     NM_DEVICE_TYPE_WIFI = 2
-    # The device is a GSM-based cellular WAN device. 
+    # The device is a GSM-based cellular WAN device.
     NM_DEVICE_TYPE_GSM = 3
-    # The device is a CDMA/IS-95-based cellular WAN device. 
+    # The device is a CDMA/IS-95-based cellular WAN device.
     NM_DEVICE_TYPE_CDMA = 4
 
     def __init__(self):
         self.bus = dbus.SystemBus()
-        self.proxy = self.bus.get_object("org.freedesktop.NetworkManager", 
+        self.proxy = self.bus.get_object("org.freedesktop.NetworkManager",
                                          "/org/freedesktop/NetworkManager")
 
     @staticmethod
@@ -186,18 +194,19 @@ class NetworkManagerHelper(object):
             res |= mmhelper.is_cdma_roaming()
         return res
 
+
 if __name__ == "__main__":
-    
+
     # test code
     if sys.argv[1:] and sys.argv[1] == "--test":
         mmhelper = ModemManagerHelper()
-        print "is_gsm_roaming", mmhelper.is_gsm_roaming()
-        print "is_cdma_romaing", mmhelper.is_cdma_roaming()
+        print("is_gsm_roaming", mmhelper.is_gsm_roaming())
+        print("is_cdma_romaing", mmhelper.is_cdma_roaming())
 
     # roaming?
     nmhelper = NetworkManagerHelper()
     is_roaming = nmhelper.is_active_connection_gsm_or_cdma_roaming()
-    print "roam: ", is_roaming
+    print("roam: ", is_roaming)
     if is_roaming:
         sys.exit(1)
     sys.exit(0)
