@@ -36,7 +36,6 @@ import locale
 import logging
 import re
 import os
-import glob
 import subprocess
 import sys
 import time
@@ -79,6 +78,16 @@ class ExecutionTime(object):
         print("%s: %s" % (self.info, time.time() - self.now))
 
 
+class SoftwarePropertiesPage():
+    ubuntu_software = 0
+    other_software = 1
+    updates = 2
+    authentication = 3
+    additional_drivers = 4
+    developer_options = 5
+    ubuntu_pro = 6
+
+
 def get_string_with_no_auth_from_source_entry(entry):
     tmp = copy(entry)
     url_parts = urlsplit(tmp.uri)
@@ -96,7 +105,7 @@ def is_unity_running():
         import dbus
         bus = dbus.SessionBus()
         unity_running = bus.name_has_owner("com.canonical.Unity")
-    except:
+    except Exception as e:
         logging.exception("could not check for Unity dbus service")
     return unity_running
 
@@ -259,7 +268,7 @@ def url_downloadable(uri, debug_func=None):
     (scheme, netloc, path, querry, fragment) = urlsplit(uri)
     debug_func("s='%s' n='%s' p='%s' q='%s' f='%s'" % (scheme, netloc, path,
                                                        querry, fragment))
-    if scheme == "http":
+    if scheme in ("http", "https"):
         try:
             http_file = urlopen(HeadRequest(uri))
             http_file.close()
@@ -297,10 +306,10 @@ def init_proxy(gsettings=None):
     * then into gconf  (if gconfclient was supplied)
     """
     SYNAPTIC_CONF_FILE = "/root/.synaptic/synaptic.conf"
-    proxy = None
+    proxies = {}
     # generic apt config wins
     if apt_pkg.config.find("Acquire::http::Proxy") != '':
-        proxy = apt_pkg.config.find("Acquire::http::Proxy")
+        proxies["http"] = apt_pkg.config.find("Acquire::http::Proxy")
     # then synaptic
     elif os.path.exists(SYNAPTIC_CONF_FILE):
         cnf = apt_pkg.Configuration()
@@ -310,18 +319,26 @@ def init_proxy(gsettings=None):
             proxy_host = cnf.find("Synaptic::httpProxy")
             proxy_port = str(cnf.find_i("Synaptic::httpProxyPort"))
             if proxy_host and proxy_port:
-                proxy = "http://%s:%s/" % (proxy_host, proxy_port)
+                proxies["http"] = "http://%s:%s/" % (proxy_host, proxy_port)
+    if apt_pkg.config.find("Acquire::https::Proxy") != '':
+        proxies["https"] = apt_pkg.config.find("Acquire::https::Proxy")
+    elif "http" in proxies:
+        proxies["https"] = proxies["http"]
     # if we have a proxy, set it
-    if proxy:
+    if proxies:
         # basic verification
-        if not re.match("http://\w+", proxy):
-            print("proxy '%s' looks invalid" % proxy, file=sys.stderr)
-            return
-        proxy_support = ProxyHandler({"http": proxy})
+        for proxy in proxies.values():
+            if not re.match("https?://\w+", proxy):
+                print("proxy '%s' looks invalid" % proxy, file=sys.stderr)
+                return
+        proxy_support = ProxyHandler(proxies)
         opener = build_opener(proxy_support)
         install_opener(opener)
-        os.putenv("http_proxy", proxy)
-    return proxy
+        if "http" in proxies:
+            os.putenv("http_proxy", proxies["http"])
+        if "https" in proxies:
+            os.putenv("https_proxy", proxies["https"])
+    return proxies
 
 
 def on_battery():
@@ -361,16 +378,14 @@ def inhibit_sleep():
         from gi.repository import Gio, GLib
         connection = Gio.bus_get_sync(Gio.BusType.SYSTEM)
 
-        var, fdlist = connection.call_with_unix_fd_list_sync('org.freedesktop.login1',
-                                                       '/org/freedesktop/login1',
-                                                       'org.freedesktop.login1.Manager',
-                                                       'Inhibit',
-                                                        GLib.Variant('(ssss)',
-                                                                    ('shutdown:sleep',
-                                                                     'UpdateManager',
-                                                                     'Updating System',
-                                                                     'block')),
-                                                        None, 0, -1, None, None)
+        var, fdlist = connection.call_with_unix_fd_list_sync(
+            'org.freedesktop.login1', '/org/freedesktop/login1',
+            'org.freedesktop.login1.Manager', 'Inhibit',
+            GLib.Variant('(ssss)',
+                         ('shutdown:sleep',
+                          'UpdateManager', 'Updating System',
+                          'block')),
+            None, 0, -1, None, None)
         inhibitor = Gio.UnixInputStream(fd=fdlist.steal_fds()[var[0]])
 
         return inhibitor
@@ -378,6 +393,7 @@ def inhibit_sleep():
         #print("could not send the dbus Inhibit signal: %s" % e)
         return False
 
+
 def str_to_bool(str):
     if str == "0" or str.upper() == "FALSE":
         return False
@@ -495,7 +511,7 @@ def is_port_already_listening(port):
     STATE_LISTENING = '0A'
     # read the data
     with open("/proc/net/tcp") as net_tcp:
-        for line in net_tcp:
+        for line in net_tcp.readlines():
             line = line.strip()
             if not line:
                 continue
