@@ -161,10 +161,10 @@ class InternalDialog(BuilderDialog):
             if self._is_livepatch_supported() and \
                self.settings_button and \
                self.settings.get_int('launch-count') >= 4:
-                self.set_desc(_("<b>Tip:</b> You can use Livepatch to "
-                                "keep your computer more secure between "
-                                "restarts."))
-                self.settings_button.set_label(_("Settings & Livepatch…"))
+                self.set_desc(_("<b>Tip:</b> You can use Livepatch with "
+                                "Ubuntu Pro to keep your computer more "
+                                "secure between restarts."))
+                self.settings_button.set_label(_("Settings & Pro…"))
             return
 
         needs_reschedule = False
