@@ -253,7 +253,8 @@ class UpdateManager(Gtk.Window):
     def _fetch_ua_updates(self):
         try:
             self.ua_updates = ua.updates().updates
-        except:
+        except Exception as e:
+            print("Error running updates end-point: ", e)
             self.ua_updates = []
 
     def _get_ua_security_status(self):
