@@ -36,6 +36,7 @@ from UpdateManager.Core.MetaRelease import (
     MetaReleaseCore,
     MetaReleaseParseError,
 )
+from UpdateManager.Core.utils import url_downloadable
 
 CURDIR = os.path.dirname(os.path.abspath(__file__))
 
@@ -101,6 +102,18 @@ class TestMetaReleaseCore(unittest.TestCase):
                              "but expected '%s''" % (current, new_dist.name,
                                                      next))
 
+    @unittest.skipUnless(url_downloadable(
+        "https://ubuntu.com", logging.debug),
+        "Could not reach https test site")
+    def test_https_url_downloadable(self):
+        with EnvironmentVarGuard() as environ:
+            logging.debug("no proxy, https address")
+            del environ["http_proxy"]
+            install_opener(None)
+            self.assertTrue(url_downloadable("https://ubuntu.com",
+                            logging.debug),
+                            "download https with no proxy failed")
+
     def test_url_downloadable(self):
         from UpdateManager.Core.utils import url_downloadable
         with EnvironmentVarGuard() as environ:
@@ -131,12 +144,12 @@ class TestMetaReleaseCore(unittest.TestCase):
                             logging.debug),
                             "download with no proxy failed")
 
-            logging.debug("no proxy, no valid adress")
+            logging.debug("no proxy, no valid address")
             self.assertFalse(url_downloadable("http://archive.ubuntu.com/xxx",
                                               logging.debug),
                              "download with no proxy failed")
 
-            logging.debug("proxy, no valid adress")
+            logging.debug("proxy, no valid address")
             environ["http_proxy"] = "http://localhost:%s" % self.port
             install_opener(None)
             self.assertFalse(url_downloadable("http://archive.ubuntu.com/xxx",
@@ -154,7 +167,7 @@ class TestMetaReleaseCore(unittest.TestCase):
     def test_html_uri_real(self):
         # test parsing of a meta-releaes file from the server
         with EnvironmentVarGuard() as environ:
-            environ["META_RELEASE_FAKE_CODENAME"] = "lucid"
+            environ["META_RELEASE_FAKE_CODENAME"] = "bionic"
             meta = MetaReleaseCore(forceDownload=True)
             while meta.downloading:
                 time.sleep(0.1)
